/****************************************************************************
 *   Copyright (C) 2004 by Arboretum Systems, Inc.                          *
 *   Technical administrator: Alain Mazy, hav@mazy.be                       *
 *   Lead program designer: Georges Jaroslaw, gjaro@arboretum.com           *
 *                                                                          *
 *   HyperEngine-AV is a video, audio and text editor that can be used to   *
 *   record, import, edit, process and arrange together video, sound and    *
 *   text. These are all achieved in the program's free-form document       *
 *   window, with no limitations to the number of tracks.                   *
 *   The purpose of this program is to provide to users at all levels of    *
 *   expertise a readily accessible tool enabling them to create movies,    *
 *   slide shows or presentations.                                          *
 *                                                                          *
 *   HyperEngine-AV itself is free software. However, plug-ins that can be  *
 *   used as add-ons to HyperEngine-AV may or may not be free software, at  *
 *   the discretion of each plug-in developer and as specified by these     *
 *   plug-ins' respective licenses.                                         *
 *   You can redistribute HyperEngine-AV itself and/or modify it under the  *
 *   terms of the GNU General Public License as published by the Free       *
 *   Software Foundation; either version 2 of the License, or (at your      *
 *   option) any later version.                                             *
 *                                                                          *
 *   HyperEngine-AV is distributed in the hope that it will be useful, but  *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of             *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *   GNU General Public License for all applicable details.                 *
 *                                                                          *
 *   You should have received a copy of the GNU General Public License      *
 *   along with this program; if not, write to:                             *
 *   Free Software Foundation, Inc.,                                        *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.              *
 ****************************************************************************/
 
#define ArmeErrors_h
#ifndef ArmeErrors_h
#include "ArmeErrors.h"
#endif //ArmeErrors_h

#ifndef ZzException_h
#include "ZzException.h"
#endif //ZzException_h


#ifndef ZzException_h
#include "ZzException.h"
#endif //ZzException_h

enum ArmeErrType
{
#define ARME_ERROR_DEF(a) a,
#include "ArmeErrorsInternal.h"
	kArmeErrForce32Bit = 0xffffffff // force 32 bit
};

struct ArmeErr
{
	ArmeErrType	type;
	void*		data;
	
	ArmeErr();
	ArmeErr(ArmeErrType	_type);
};

inline ArmeErr::ArmeErr()
{
	type = kArmeOK;
	data = 0;
}

inline ArmeErr::ArmeErr(ArmeErrType	_type)
{
	type = _type; 
	data = 0;
}

const char* ArmeGetQTError(short err);

const char* ArmeGetStringFromError(ArmeErr err);

#ifdef SHOW_DEBUG_INFO_IN_ERROR_MSG

#define ThrowOnOSStatus(st) ThrowOnOSStatusFunction(st, __FILE__, __LINE__)
bool ThrowOnOSStatusFunction(OSStatus st, const char* sourceFile, int lineNumber);
#define ThrowOnArmeErr(err) ThrowOnArmeErrFunction(err, __FILE__, __LINE__)
bool ThrowOnArmeErrFunction(ArmeErr err, const char* sourceFile, int lineNumber);

#else //SHOW_DEBUG_INFO_IN_ERROR_MSG

#define ThrowOnOSStatus(st) ThrowOnOSStatusFunction(st, "", 0)
bool ThrowOnOSStatusFunction(OSStatus st, const char* sourceFile, int lineNumber);
#define ThrowOnArmeErr(err) ThrowOnArmeErrFunction(err, "", 0)
bool ThrowOnArmeErrFunction(ArmeErr err, const char* sourceFile, int lineNumber);

#endif //SHOW_DEBUG_INFO_IN_ERROR_MSG

class ZzExceptionArmeErr : public ZzException
{
public :
#ifdef SHOW_DEBUG_INFO_IN_ERROR_MSG
	ZzExceptionArmeErr(ArmeErr armeErr, const char* sourceFile, int lineNumber) : ZzException(sourceFile, lineNumber) { fArmeErr = armeErr; };
#else
	ZzExceptionArmeErr(ArmeErr armeErr) : ZzException() { fArmeErr = armeErr; };
#endif SHOW_DEBUG_INFO_IN_ERROR_MSG
	virtual const char* ErrorMessage();
private :
	ArmeErr fArmeErr;
};

